@@ -18,19 +18,18 @@
 require 'spec_helper'
 
 describe 'client#clear_scroll' do
-
   let(:expected_args) do
     [
       'DELETE',
       '_search/scroll',
       {},
-      { scroll_id: 'abc123' },
+      { scroll_id: 123 },
       {},
       { endpoint: 'clear_scroll' }
     ]
   end
 
   it 'performs the request' do
-    expect(client_double.clear_scroll(body: { scroll_id: 'abc123' })).to be_a Elasticsearch::API::Response
+    expect(client_double.clear_scroll(body: { scroll_id: 123 })).to be_a Elasticsearch::API::Response
   end
 end
