@@ -20,16 +20,16 @@ require 'spec_helper'
 describe 'client#eql.search' do
   let(:expected_args) do
     [
-      'GET',
+      'POST',
       'foo/_graph/explore',
       {},
-      nil,
+      {},
       {},
       { defined_params: { index: 'foo' }, endpoint: 'graph.explore' }
     ]
   end
 
   it 'performs the request' do
-    expect(client_double.graph.explore(index: 'foo')).to be_a Elasticsearch::API::Response
+    expect(client_double.graph.explore(index: 'foo', body: {})).to be_a Elasticsearch::API::Response
   end
 end
