@@ -17,19 +17,19 @@
 
 require 'spec_helper'
 
-describe 'client.cluster#put_data_stream_options' do
+describe 'client.indices#put_data_stream_options' do
   let(:expected_args) do
     [
       'PUT',
       '_data_stream/foo/_options',
       {},
-      nil,
+      {},
       {},
       { endpoint: 'indices.put_data_stream_options', defined_params: { name: 'foo' } }
     ]
   end
 
   it 'performs the request' do
-    expect(client_double.indices.put_data_stream_options(name: 'foo')).to be_a Elasticsearch::API::Response
+    expect(client_double.indices.put_data_stream_options(name: 'foo', body: {})).to be_a Elasticsearch::API::Response
   end
 end
